<?php
/*
Plugin Name: Filez
Plugin URI: http://familypress.net/filez/
Description: Popup file upload tool. Adds a Filez button to the WP toolbars, which launches a popup file uploader/browser that can insert links into posts. See Options:Filez for configuration and Management:Filez for a crude file manager.
Version: 0.5
Author: Isaac Wedin
Author URI: http://familypress.net/
*/

/* INSTALLATION
Extract the archive into your WP plugins folder. Create a files folder in your wp-content folder and make it writable. Activate the plugin. Configure the options at Options:Filez, verifying the path and address. I suggest setting the maximum file size just under the maximum in your server's php.ini. Using the tags option may suck if you later remove Filez. To uninstall, deactivate and delete the plugin folder. To upgrade, delete the old plugin folder and install/upload the new one.
*/

/* Copyright 2005, 2006, 2007  Isaac Wedin (email : isaac@familypress.net)
This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version. 

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

require_once(ABSPATH . 'wp-content/plugins/filez/include.php');
require_once(ABSPATH . 'wp-content/plugins/filez/buttons.php');

// inserts javascript to launch the Filez popup into the admin header
function filez_popup_js() {
	echo '
<script language="JavaScript" type="text/javascript">
//<![CDATA[
	function filez_popup() {
		var mylink = "' . get_settings('siteurl') . '/wp-content/plugins/filez/popup.php?action=upload";
		var windowname = "Filez";
		if (! window.focus) return true;
			var href;
		if (typeof(mylink) == "string")
			href = mylink;
		else
			href = mylink.href;
		window.open(href, windowname, "width=400,height=400,scrollbars=yes");
		return false;
	}
//]]>
</script>
	';
}

add_action('admin_head','filez_popup_js');

// the 8 means only admins will see the Filez Options
function filez_add_options_page() {
	add_options_page('Filez', 'Filez', 'manage_options', basename(__FILE__), 'filez_options_subpanel');
}

// generates the Filez Options subpanel
function filez_options_subpanel() {
	global $filez_options;
	$icon_path = ABSPATH . 'wp-content/plugins/filez/plugins/filez/images/';
	if (isset($_POST['filez_options_update'])) { // update the options and refresh the options array with the updated options
		if (isset($_POST['icon'])) {
			if (!copy($icon_path . $_POST['icon'], $icon_path . 'filez.png')) {
				echo '<div class="updated">' . __('Failed to switch icon, check file and folder permissions.','filez') . "</div>\n";
			}
		}
	   $filez_updated_options = array();
		$filez_updated_options = $_POST;
		add_option('filez_options');
		update_option('filez_options', $filez_updated_options);
		$filez_options = get_option('filez_options');
		echo '<div class="updated">' . __('Filez options updated.','filez') . "</div>\n";
	}
	$icon_url = get_settings('siteurl') . '/wp-content/plugins/filez/plugins/filez/images/';
	$filez_icons = filez_folder_contents($icon_path);
	echo '
	<div class="wrap">
	<h2>' . __('Filez Options','filez') . '</h2>
	<form name="filez_options" method="post">
	<input type="hidden" name="filez_options_update" value="update" />
	<fieldset class="options">
	<table width="100%" cellspacing="2" cellpadding="5" class="editform">
		<tr>
			<th scope="row">' . __('Files path:','filez') . '</th>
			<td><input name="path" type="text" id="path" value="' . $filez_options['path'] . '" size="38" /><br />
			' . __('Suggested path:','filez') . ' <code>' . ABSPATH . 'wp-content/files/</code> ' . __('Make sure the folder exists and is writable.',filez) . '</td>
		</tr>
		<tr>
			<th scope="row">' . __('Files address:','filez') . '</th>
			<td><input name="address" type="text" id="address" value="' . $filez_options['address'] . '" size="38" /><br />
			' . __('Suggested address:','filez') . ' <code>' . get_settings('siteurl') . '/wp-content/files/</code></td>
		</tr>
		<tr>
			<th scope="row">' . __('Capability required to use Filez:','filez') . '</th>
			<td><input name="capability" type="text" id="capability" value="' . $filez_options['capability'] . '" size="20"><br />
		' . __('You probably want to use <code>edit_posts</code>, but you could also use <code>upload_files</code>, <code>publish_posts</code> or any other capability you want.','filez') . '</td>
		</tr>
		<tr>
			<th scope="row">' . __('Allowed extensions:','filez') . '</th>
			<td><input name="extensions" type="text" id="extensions" value="' . $filez_options['extensions'] . '" size="38" /><br />
			' . __('Separate with spaces (such as <code>jpg mpg zip</code>), leave empty to allow all. No dots allowed, so for <code>tar.gz</code> just use <code>gz</code>.','filez') . '</td>
		</tr>
		<tr>
			<th scope="row">' . __('Insert tags or HTML:','filez') . '</th>
			<td><label><input name="use_tags" type="radio" value="1" ';
			if ($filez_options['use_tags'] == '1') {echo 'checked="checked" ';}
			echo '/> ' . __('Tags','filez') . '</label><br />
			<label><input name="use_tags" type="radio" value="0" ';
			if ($filez_options['use_tags'] == '0') {echo 'checked="checked" ';}
			echo ' /> ' . __('HTML','filez') . '</label><br />' . __('Tags look like [filez:bla.zip] and are turned into links when the post is displayed. They look nice, but Filez needs to be active for them to work. HTML is a better choice if you might stop using Filez.','filez') . '</td>
		</tr>
		<tr>
			<th scope="row">' . __('Choose an icon:','filez') . '</th>
			<td>';
			foreach ($filez_icons as $icon) {
				if ($icon != 'filez.png') {
					echo '<label><input name="icon" type="radio" value="' . $icon . '" /> <img src="' . $icon_url . $icon . '" alt="' . $icon . '" /></label><br />';
				}
			}
			echo __('You can choose one of these icons. Add more at <code>wp-content/plugins/filez/plugins/filez/images/</code>, based on the ones that are there. Make sure the folder and files are writable for this to work.','filez') . '</td>
		</tr>
	</table> 
	</fieldset>

	<p class="submit"><input type="submit" name="Submit" value="' . __('Update Options &raquo;','filez') . '" /></p>
</form> 
</div>
';
}

add_action('admin_menu', 'filez_add_options_page');

// makes the Filez Management page
function filez_management() {
	global $filez_options;
	if (isset($_POST['filez_update'])) {
		foreach((array)$_POST as $key=>$val) {
			if(is_array($val)) {
				if ($val['action'] == 'delete') {
					$file_to_delete = $filez_options['path'] . $val['file'];
					@unlink($file_to_delete);
					if (is_file($file_to_delete)) {
						echo '<div class="updated">' . __('File delete failed.','filez') . '</div>';
					} else {
						echo '<div class="updated">' . __('File deleted.','filez') . '</div>';
					}
				} elseif ($val['action'] == 'rename') {
					$file_to_rename = $filez_options['path'] . $val['file'];
					$new_name = $filez_options['path'] . $val['rename'];
					@rename($file_to_rename,$new_name);
					if (is_file($new_name) && !is_file($file_to_rename)) {
						echo '<div class="updated">' . __('File renamed.','filez') . '</div>';
					} else {
						echo '<div class="updated">' . __('File rename failed.','filez') . '</div>';
					}
				}
			}
		}
	}
	echo '
	<div class="wrap">
	<h2>' . __('Filez Management','filez') . '</h2>
	';
	if (!is_dir($filez_options['path'])) {
		echo '<p>' . __('Folder not found at:','filez') . ' <code>' . $filez_options['path'] . '</code></p>
			<p>' . __('Create the folder, make it writable, and verify or enter the path on the ','filez') . '<a href="' . get_settings('siteurl') . '/wp-admin/options-general.php?page=filez.php">' . __('Filez Options page','filez') . '</a>.</p>
		';
	} else {
		$filez_list = array();
		$filez_list = filez_folder_contents($filez_options['path']); // get the list after deleting and renaming
		if (empty($filez_list)) {
			echo '<p>' . __('No files found at:','filez') . ' <code>' . $filez_options['path'] . '</code></p>
			';
		}
	echo '<p>' . __('You can use the','filez') . ' <a href="#" onclick="return filez_popup();">' . __('popup Uploader','filez') . '</a> ' . __('to upload some files.','filez') . '</p>
	';
	}
	echo '</div>
	';
	if (!empty($filez_list)) {
		if (isset($_GET['page'])) {
			$current_page = $_GET['page'];
		} else {
			$current_page = 1;
		}
		echo '<div class="wrap">
		';
		$files_per_page = 50;
		$files_count = count($filez_list);
		$pages = (int)(($files_count/$files_per_page) + 1);
		echo '<p>';
		if ($pages > 1) {
			for ($i = 1; $i <= $pages; $i++) {
				if ($i != $current_page) {
					echo '<a href="edit.php?page=filez.php&amp;filez=' . $i . '">';
				}
				echo __('Page','filez') . ' ' . $i;
				if ($i != $current_page) {
					echo '</a>';
				}
				if ($i < $pages) {
					echo ' | ';
				}
			}
			$list_start = ($current_page - 1) * $files_per_page;
			$current_file_list = array_slice($filez_list, $list_start, $files_per_page);
		} else { // there's only one page so let's show the whole list
			$current_file_list = $filez_list;
		}
		echo '</p>';
		echo '<form name="filez" method="post">
		<input type="hidden" name="filez_update" value="update" />
		<table>
		<tr>
		<th scope="col">' . __('Filename','filez') . '</th>
		<th scope="col">' . __('Action','filez') . '</th>
		<th scope="col">' . __('New Name','filez') . '</th>
		</tr>
		';
		$i = 1;
		foreach ((array)$current_file_list as $file) {
			echo "\n<tr>\n";
			echo '<td><input type="hidden" name="row' . $i . '[file]" value="' . $file . '" /><a href="' . $filez_options['address'] . $file . '">' . $file . '</a></td>
			<td><select name="row' . $i . '[action]">
				<option value="nothing" selected="selected">' . __('Do Nothing','filez') . '</option>
				<option value="delete">' . __('Delete','filez') . '</option>
				<option value="rename">' . __('Rename','filez') . '</option>
			</select></td>
			<td><input type="text" size="27" name="row' . $i . '[rename]" value="" /></td>
			</tr>
			';
			$i++;
		}
		echo '
		</table>
		<p class="submit"><input type="submit" name="Submit" value="' . __('Update','filez') . ' &raquo;" /></p>
		</form>
		</div>
		';
	}
}

function filez_add_management_page() {
	global $filez_options;
	add_management_page('Filez', 'Filez', 'manage_options', basename(__FILE__), 'filez_management');
}

add_action('admin_menu', 'filez_add_management_page');

function filez_make_link($stuff) {
	global $filez_options;
	$file = explode(',',$stuff);
	return '<a href="' . $filez_options['address'] . $file[0] . '" title="' . $file[0] . '">' . $file[0] . '</a>';
}

function filez_tag_process($content = '') {
	global $filez_options;
	return preg_replace( "/\[filez\:(.*?)\]/e","filez_make_link('\\1')", $content);
}

add_filter('the_content', 'filez_tag_process');
?>
